Module message

Module message 

Functions

emit_config
Emit a config type: interface only (no codec).
emit_message
Emit a complete message: interface + encode function + decode function.
emit_read
Emit code to read a value from a BitReader and bind to var_name.
emit_write
Emit code to write a value to a BitWriter.
is_byte_aligned
Returns true if the type is byte-aligned (i.e., not sub-byte).