Functions
- emit_
config - Emit a config type: interface only (no codec).
- emit_
message - Emit a complete message: interface + encode function + decode function.
- emit_
read - Emit code to read a value from a BitReader and bind to
var_name. - emit_
write - Emit code to write a value to a BitWriter.
- is_
byte_ aligned - Returns true if the type is byte-aligned (i.e., not sub-byte).